@@ -2,6 +2,10 @@
   is.numeric(x) && all(is.finite(x)) && !any(is.na(x)) && all(trunc(x) == x)
 }
 
+.isPoint <- function(M){
+  is.numeric(M) && length(M) == 2L && !any(is.na(M)) && all(is.finite(M))
+}
+
 .toCplx <- function(M){
   if(isTRUE(all.equal(M, Inf, check.attributes = FALSE))){
     Inf
@@ -30,6 +34,10 @@
   sqrt(c(crossprod(v)))
 }
 
+.isAlmostZero <- function(x){
+  isTRUE(all.equal(x + 1, 1, tol = 1e-6))
+}
+
 .LineLineIntersection <- function (P1, P2, Q1, Q2) {
   dx1 <- P1[1L] - P2[1L]
   dx2 <- Q1[1L] - Q2[1L]
